@@ -11,8 +11,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 #include <errno.h>
 
@@ -838,11 +838,11 @@ void Atlantik::closeEvent(QCloseEvent *e)
 	Game *gameSelf = m_atlanticCore->gameSelf();
 	Player *playerSelf = m_atlanticCore->playerSelf();
 
-	int result = KMessageBox::Yes;
+	int result = KMessageBox::Continue;
 	if ( gameSelf && !playerSelf->isBankrupt() && m_runningGame )
-		result = KMessageBox::warningYesNo( this, i18n("You are currently part of an active game. Are you sure you want to close Atlantik? If you do, you forfeit the game."), i18n("Close & Forfeit?") );
+		result = KMessageBox::warningContinueCancel( this, i18n("You are currently part of an active game. Are you sure you want to close Atlantik? If you do, you forfeit the game."), i18n("Close & Forfeit?"), i18n("Close && Forfeit") );
 
-	if ( result == KMessageBox::Yes )
+	if ( result == KMessageBox::Continue )
 	{
 		if ( m_atlantikNetwork )
 			m_atlantikNetwork->leaveGame();
