@@ -15,9 +15,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbg.cpp 328532 2004-07-13 00:20:01Z bmeyer $
+  $Id: kbg.cpp 640692 2007-03-08 20:28:37Z lueck $
 
 */
 
@@ -86,9 +86,6 @@ KBg::KBg()
 	helpTopic[RuleHome][0] = i18n("Backgammon Rules");
 	helpTopic[RuleHome][1] = "http://www.bkgm.com/rules.html";
 
-	helpTopic[SelfHome][0] = i18n("KBackgammon");
-	helpTopic[SelfHome][1] = PROG_HOME;
-
 	/*
 	 * The main view is shared between the board and a small text window
 	 */
@@ -140,8 +137,6 @@ KBg::KBg()
 		     actionCollection(), "help_www_fibs"))->plug(p);
 	(new KAction(helpTopic[RuleHome][0], 0, this, SLOT(wwwRule()),
 		     actionCollection(), "help_www_rule"))->plug(p);
-	(new KAction(helpTopic[SelfHome][0], 0, this, SLOT(wwwHome()),
-		     actionCollection(), "help_www_home"))->plug(p);
 
 	/*
 	 * Set up the command line - using actions, otherwise recreating the GUI will delete them
@@ -709,7 +704,6 @@ void KBg::newToolbarConfig()
  * Help slots
  */
 void KBg::wwwFIBS() {showWWW(FIBSHome);}
-void KBg::wwwHome() {showWWW(SelfHome);}
 void KBg::wwwRule() {showWWW(RuleHome);}
 
 void KBg::showWWW(int t)
