@@ -84,14 +84,9 @@ public slots:
   void optionShowSpy(bool);
   void toggleMenubar();
   void configure();
-  void configureKeys();
-  void configureToolbars();
   void setLevel(int);
   void setIPlay(int);
 
-private slots:
-  void newToolbarConfig();
-
 private:
   void setupActions();
   void updateStatus();
