@@ -1210,12 +1210,13 @@ Move& Board::bestMove()
 	if (spyLevel>0)
 	  printf("\n> New Search\n>\n");
 
+	/* iterative deepening loop */
 	do {
 	  if (spyLevel>0)
 	    printf(">   MaxDepth: %d\n>\n", maxDepth);
 
-		// ShowTiefe(maxtiefe);
-		do {
+		/* searches on same level with different alpha/beta windows */
+		while(1) {
 		  if (spyLevel>0)
 		    printf(">     AB-Window: (%d ... %d)\n>\n", alpha, beta);
 
@@ -1264,36 +1265,30 @@ Move& Board::bestMove()
 		  if (_bestMove.type == Move::none)
 		    breakOut=false;
 
+                  if (breakOut) break;
+
                   // widen alpha-beta window if needed
 		  if (actValue <= nalpha) {
 		    alpha = -15000;
                     if (beta<15000) beta=actValue+1;
+		    continue;
                   }
 		  if (actValue >= nbeta) {
                     if (alpha > -15000) alpha = actValue-1;
                     beta=15000;
+		    continue;
                   }
+		  break; 
 		}
-		while(!breakOut && (actValue<=nalpha || actValue>=nbeta));
 
 		/* Window in both directions cause of deepening */
 		alpha=actValue-200, beta=actValue+200;
-		/*
-		  if ( (maxDepth+((color == color2)?1:0)) %2 ==1)
-		  alpha=actValue-200, beta=actValue+1;
-		  else
-		  alpha=actValue-1, beta=actValue+200;
-		*/
-		// ShowHv2();
-		/*
-		  if (spyLevel>0) {
-		  printf(">>> Best Move so far: %d - ", actValue);
-		  pv[0].print();
-		  printf("\n");
-		  }
-		*/
+
+		if (breakOut) break;
+
+		maxDepth++;
 	}
-	while(++maxDepth< realMaxDepth && !breakOut);
+	while(maxDepth <= realMaxDepth);
 
 	/* If Spy is On, we want replayable search: don't change rating! */
 	if (spyLevel==0)
