@@ -47,7 +47,7 @@ class Board : public QObject
 
  public:
   Board();
-  ~Board() {};
+  ~Board() {}
 
   /* different states of one field */
   enum {
