@@ -622,7 +622,7 @@ void BoardWidget::choseMove(MoveList *pl)
     gettingMove = true;
     mbDown = false;
     actValue = - board.calcEvaluation();
-    kdDebug() << "Chose Move..." << endl;
+    kdDebug(12011) << "Chose Move..." << endl;
   }
 }
 
@@ -636,7 +636,7 @@ int BoardWidget::positionOf(int xx, int yy)
   int y = (1000 * (yy- (height()-boardSize)/2)) / boardSize;
   
   /*
-  kdDebug() << "(" << xx << "," << yy << ") -> ("
+  kdDebug(12011) << "(" << xx << "," << yy << ") -> ("
 	    << x << "," << y << ")" << endl;
   */
 
@@ -653,14 +653,14 @@ int BoardWidget::positionOf(int xx, int yy)
 bool isBetweenFields(int pos)
 {
   bool res = ( ((pos%2) == 1) || ( ((pos/22)%2) == 1) );
-  //  kdDebug() << "Pos " << pos << " is between fields: " << res << endl;
+  //  kdDebug(12011) << "Pos " << pos << " is between fields: " << res << endl;
   return res;
 }
 
 int fieldOf(int pos)
 {
   int f = 11*(pos/44) + (pos%22)/2;
-  //  kdDebug() << "Field1 of pos " << pos << " is " << f << endl;
+  //  kdDebug(12011) << "Field1 of pos " << pos << " is " << f << endl;
   return f;
 }
 
@@ -681,7 +681,7 @@ int field2Of(int pos)
     f2 = f1 + ( ((x%2)==0) ? 11:12 );
   }
 
-  //  kdDebug() << "Field2 of pos " << pos << " is " << f2 << endl;
+  //  kdDebug(12011) << "Field2 of pos " << pos << " is " << f2 << endl;
   return f2;
 }
 
@@ -878,7 +878,7 @@ void BoardWidget::mousePressEvent( QMouseEvent* pEvent )
   }
 
   startValid = isValidStart(pos, (pEvent->button() == MidButton));
-  kdDebug() << "Start pos " << pos << " is valid: " << startValid << endl;
+  kdDebug(12011) << "Start pos " << pos << " is valid: " << startValid << endl;
   //  actMove.print();
 
   if (!startValid) return;
@@ -919,7 +919,7 @@ void BoardWidget::mouseMoveEvent( QMouseEvent* pEvent )
     /* We haven't a valid move yet. Check if we are over a valid start */
 
     startValid = isValidStart(pos, (pEvent->button() == MidButton));
-    kdDebug() << "Start pos " << pos << " is valid: " << startValid << endl;
+    kdDebug(12011) << "Start pos " << pos << " is valid: " << startValid << endl;
     //    actMove.print();
 
     if (!startValid) return;
@@ -1019,13 +1019,9 @@ void BoardWidget::mouseReleaseEvent( QMouseEvent* pEvent )
   emit updateSpy(tmp);
 }
 
-
-
-
-
-
-
-
-
+QSize  BoardWidget::sizeHint() const
+{
+   return QSize(400, 350);
+}
 
 #include "BoardWidget.moc"
