@@ -22,7 +22,7 @@ class FEBoard : public Board
 	// standard methods
 	bool afterGlue(bool doAll, bool first);
 	AfterRemoveResult afterRemove(bool doAll, bool first);
-	bool afterGift(bool first) { return !doFall(false, first, true); };
+	bool afterGift(bool first) { return !doFall(false, first, true); }
     void removeBlock(const KGrid2D::Coord &);
     bool toBeRemoved(const KGrid2D::Coord &) const;
     bool toFall(const KGrid2D::Coord &) const;
