@@ -40,7 +40,7 @@ BoardWidget::BoardWidget( QWidget* parent, const char *name )
 
     // Load tileset. First try to load the last use tileset
     QString tFile;
-    getFileOrDefault(tileFile, "tileset", tFile);
+    getFileOrDefault(Prefs::tileSet(), "tileset", tFile);
 
     if (!loadTileset(tFile)){
         KMessageBox::error(this,
@@ -49,7 +49,7 @@ BoardWidget::BoardWidget( QWidget* parent, const char *name )
         kapp->quit();
     }
 
-    getFileOrDefault(backgroundFile, "bgnd", tFile);
+    getFileOrDefault(Prefs::background(), "bgnd", tFile);
 
     // Load background
     if( ! loadBackground(tFile, false ) )
@@ -60,7 +60,7 @@ BoardWidget::BoardWidget( QWidget* parent, const char *name )
 	kapp->quit();
     }
 
-    getFileOrDefault(layout, "layout", tFile);
+    getFileOrDefault(Prefs::layout(), "layout", tFile);
     if( ! loadBoardLayout(tFile) )
     {
 	KMessageBox::error(this,
@@ -77,15 +77,6 @@ BoardWidget::~BoardWidget(){
 }
 
 void BoardWidget::loadSettings(){
-  tileFile = Prefs::tileSet();
-  backgroundFile = Prefs::background();
-  layout = Prefs::layout();
-
-  //loadTileset(tileFile);
-  //loadBoardLayout(layout);
-  // TODO somehow...
-  //theBackground.load(backgroundFile);
-
   theBackground.tile = Prefs::tiledBackground();
 
   setDisplayedWidth();
@@ -110,9 +101,7 @@ void BoardWidget::getFileOrDefault(QString filename, QString type, QString &res)
 	picsPos += "default.";
 	picsPos += type;
 
-	QFile test;
-	test.setName(filename);
-	if (test.exists()) {
+	if (QFile::exists(filename)) {
 		res = filename;
 	}
     else {
@@ -1548,7 +1537,14 @@ void BoardWidget::hilightTile( POSITION& Pos, bool on, bool doRepaint )
 	}
 	if (doRepaint) {
 		updateBackBuffer=true;
-		repaint(false);
+		if (testWFlags(WNoAutoErase)) 
+			update(); 
+		else 
+		{ 
+			setWFlags(getWFlags() | WNoAutoErase ); 
+			update(); 
+			setWFlags(getWFlags() & (~WNoAutoErase) ); 
+		} 
 	}
 }
 
@@ -1558,7 +1554,14 @@ void BoardWidget::hilightTile( POSITION& Pos, bool on, bool doRepaint )
 void BoardWidget::drawBoard(bool )
 {
    updateBackBuffer=true;
-   repaint(false);
+   if (testWFlags(WNoAutoErase)) 
+      update(); 
+   else 
+   { 
+      setWFlags(getWFlags() | WNoAutoErase ); 
+      update(); 
+      setWFlags(getWFlags() & (~WNoAutoErase) ); 
+   } 
    drawTileNumber();
 }
 
@@ -1574,7 +1577,14 @@ void BoardWidget::putTile( POSITION& Pos, bool doRepaint )
 	Game.hilighted[E][Y][X] = 0;
     if (doRepaint) {
 	updateBackBuffer=true;
-       repaint(false);
+	if (testWFlags(WNoAutoErase)) 
+		update(); 
+	else 
+	{ 
+		setWFlags(getWFlags() | WNoAutoErase ); 
+		update(); 
+		setWFlags(getWFlags() & (~WNoAutoErase) ); 
+	} 
     }
 }
 
@@ -1596,7 +1606,14 @@ void BoardWidget::removeTile( POSITION& Pos , bool doRepaint)
     Game.putTile( E, Y, X, 0 );
     if (doRepaint) {
         updateBackBuffer=true;
-        repaint(false);
+	if (testWFlags(WNoAutoErase)) 
+		update(); 
+	else 
+	{ 
+		setWFlags(getWFlags() | WNoAutoErase ); 
+		update(); 
+		setWFlags(getWFlags() & (~WNoAutoErase) ); 
+	} 
     }
 }
 
@@ -1790,8 +1807,9 @@ bool BoardWidget::loadBackground(
             KMessageBox::sorry(this, i18n("Failed to load image:\n%1").arg(pszFileName) );
         return( false );
     }
-    backgroundFile =  pszFileName;
-    return( true );
+    Prefs::setBackground(pszFileName);
+    Prefs::writeConfig();
+    return true;
 }
 
 // ---------------------------------------------------------
@@ -1904,17 +1922,19 @@ void BoardWidget::initialiseRemovedTiles() {
 bool BoardWidget::loadTileset(const QString &path) {
 
   if (theTiles.loadTileset(path)) {
-    tileFile = path;
-    return(true);
+    Prefs::setTileSet(path);
+    Prefs::writeConfig();
+    return true;
   } else {
-    return(false);
+    return false;
   }
 
 }
 
 bool BoardWidget::loadBoardLayout(const QString &file) {
   if (theBoardLayout.loadBoardLayout(file)) {
-    layout = file;
+    Prefs::setLayout(file);
+    Prefs::writeConfig();
     return true;
   }
   return false;
