@@ -13,7 +13,7 @@
 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "field.h"
@@ -231,14 +231,15 @@ void Field::pressClearFunction(const Coord &p, bool pressed)
 
 void Field::keyboardAutoReveal()
 {
-	pressClearFunction(_cursor, true);
+	_cursor_back = _cursor;
+	pressClearFunction(_cursor_back, true);
 	QTimer::singleShot(50, this, SLOT(keyboardAutoRevealSlot()));
 }
 
 void Field::keyboardAutoRevealSlot()
 {
-	pressClearFunction(_cursor, false);
-	doAutoReveal(_cursor);
+	pressClearFunction(_cursor_back, false);
+	doAutoReveal(_cursor_back);
 }
 
 void Field::doAutoReveal(const Coord &c)
