@@ -48,6 +48,7 @@ struct State
     QString gameData;
 };
 
+
 /***************************************************************
 
   Dealer -- abstract base class of all varieties of patience
@@ -112,9 +113,8 @@ public:
 
     void setAutoDropEnabled(bool a);
     bool autoDrop() const { return _autodrop; }
-    
-    int getMoves() const { return moves; }
-    void resetMoves() { moves = 0; }
+
+    int getMoves() const { return undoList.count(); }
 
 public slots:
 
@@ -132,7 +132,7 @@ signals:
     void gameLost();
     void saveGame(); // emergency
     void gameInfo(const QString &info);
-    void setMoves( int moves );
+    void updateMoves();
 
 public slots:
     virtual void demo();
@@ -218,10 +218,11 @@ protected:
     QString ac;
     static Dealer *s_instance;
     bool _autodrop;
-    int moves;
+    bool _gameRecorded;
 
 private:
 	 void countLoss();
+	 void countGame();
 };
 
 #endif
