@@ -104,7 +104,7 @@ bool Fortyeight::checkAdd(int, const Pile *c1, const CardList &c2) const
 
     // ok if in sequence, same suit
     return (c1->top()->suit() == c2.first()->suit())
-       && (c1->top()->value() == (c2.first()->value()+1));
+       && (c1->top()->rank() == (c2.first()->rank()+1));
 }
 
 void Fortyeight::deal()
@@ -134,50 +134,60 @@ void Fortyeight::setGameState( const QString &s )
     lastdeal = s.toInt();
 }
 
-bool Fortyeight::isGameLost() const{
-   kdDebug(11111) << "isGameLost ?" << endl;
-   if(!lastdeal)
+bool Fortyeight::isGameLost() const
+{
+    kdDebug(11111) << "isGameLost ?" << endl;
+    if(!lastdeal)
 	return false;
-   if(!deck->isEmpty())
+    if(!deck->isEmpty())
 	return false;
 
-   Card *c;
-   for(int i=0; i < 8; i++){
-	if(stack[i]->isEmpty())
-		return false;
-	c=stack[i]->top();
+    Card *c;
+    for(int i=0; i < 8; i++)
+    {
+        if(stack[i]->isEmpty())
+            return false;
 
-	if(c->value() == Card::Ace)
-		return false;
-	if(!pile->isEmpty())
-		if(pile->top()->suit() == c->suit() &&
-			pile->top()->value()+1 == c->value())
-			return false;
-	for(int j=0; j <8;j++){
-		if(target[j]->isEmpty())
-			continue;
-		if(c->suit() == target[j]->top()->suit() &&
-			c->value()-1 ==target[j]->top()->value())
-			return false;
-		}
-	for(int j=1; j < 8; j++){
-		int k=(i+j) % 8;
-		if (stack[k]->isEmpty())
-			continue;
-		if(c->suit() == stack[k]->top()->suit() &&
-			c->value()+1 ==stack[k]->top()->value()){
-			int indexi=stack[i]->indexOf(c);
-			if(indexi==0)
-				return false;
-			Card *c2=stack[i]->at(indexi-1);
-			if(c2->value()!=stack[k]->top()->value() ||
-				c2->suit()!=stack[k]->top()->suit())
-				return false;
-			}
-		}
-	}
+        c=stack[i]->top();
 
-   return true;
+        if(c->rank() == Card::Ace)
+            return false;
+
+        if(!pile->isEmpty()) {
+            if(pile->top()->suit() == c->suit() &&
+               pile->top()->rank()+1 == c->rank())
+                return false;
+
+            if ( !target[i]->isEmpty() &&
+                 pile->top()->suit() == target[i]->top()->suit() &&
+                 pile->top()->rank() == target[i]->top()->rank()+1)
+                return false;
+        }
+        for(int j=0; j <8;j++){
+            if(target[j]->isEmpty())
+                continue;
+            if(c->suit() == target[j]->top()->suit() &&
+               c->rank()-1 ==target[j]->top()->rank())
+                return false;
+        }
+        for(int j=1; j < 8; j++) {
+            int k=(i+j) % 8;
+            if (stack[k]->isEmpty())
+                continue;
+            if(c->suit() == stack[k]->top()->suit() &&
+               c->rank()+1 ==stack[k]->top()->rank()){
+                int indexi=stack[i]->indexOf(c);
+                if(indexi==0)
+                    return false;
+                Card *c2=stack[i]->at(indexi-1);
+                if(c2->rank()!=stack[k]->top()->rank() ||
+                   c2->suit()!=stack[k]->top()->suit())
+                    return false;
+            }
+        }
+    }
+
+    return true;
 }
 
 static class LocalDealerInfo8 : public DealerInfo
