@@ -296,10 +296,11 @@ void Klondike::redeal() {
         // of the new deck
         pilecards += deck->cards();
 
-    for (CardList::Iterator it = pilecards.fromLast(); it != pilecards.end(); --it)
+    for (int count = pilecards.count() - 1; count >= 0; --count)
     {
-        (*it)->setAnimated(false);
-        deck->add(*it, true, false); // facedown, nospread
+        Card *card = pilecards[count];
+        card->setAnimated(false);
+        deck->add(card, true, false); // facedown, nospread
     }
 
     redealt = true;
@@ -405,7 +406,7 @@ bool Klondike::isGameLost() const
             // ...check whether any of the other stores contains a (visible)
             // king we could move here.
             for ( int j = 0; j < 7; ++j ) {
-                if ( j == i ) {
+                if ( j == i || play[ j ]->isEmpty() ) {
                     continue;
                 }
                 const CardList cards = play[ j ]->cards();
