@@ -67,7 +67,7 @@ class Board : public QMemArray<int>
 {
 public:
   Board  (int s);
-  ~Board() {};
+  ~Board() {}
   QRect  rect(int i);
 
   void   set(int i, Square sq);
