@@ -1,7 +1,7 @@
 /* -------------------------------------------------------------
    KDE Tuberling
    Object to draw on the game board
-   mailto:ebisch@cybercable.tm.fr
+   mailto:e.bischoff@noos.fr
  ------------------------------------------------------------- */
 
 
@@ -19,8 +19,8 @@ class ToDraw
     ToDraw(const ToDraw &);
     ToDraw(int, const QRect &);
     ToDraw &operator=(const ToDraw &);
-    void draw(QPainter &, const QRect &, const QRect *, const QRect *, const QPixmap *, const QBitmap *) const;
-    bool save(FILE *) const;
+    void draw(QPainter &, const QRect &, const QRect *, const QPixmap *, const QBitmap *) const;
+    void save(FILE *) const;
     bool load(FILE *, int, bool &);
 
     inline int getNumber() const { return number; }
